/*
** Module   : ClientBuilderParameters.java
** Abstract : store the process parameters.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description--------------------------
** 001 MAG 20131119 First version.
*/

package com.goldencode.p2j.main;

import java.util.*;

/**
 * A Java Bean class to hold process parameters.
 * 
 * @author mag
 *
 */
public class ClientBuilderParameters
{   
   /** Client assigned uuid */
   private String uuid;

   /** User name */
   private String userName;
   
   /** Password */
   private String password;
   
   /** Options from directory */
   ClientBuilderOptions options;

   /**
    * Constructor. Assign a unique UUID to this process.
    */
   public ClientBuilderParameters()
   {
      options = ClientBuilderOptions.getInstance();
      uuid = UUID.randomUUID().toString();
   }
   
   /**
    * Get process assigned UUID.
    * 
    * @return  The assigned UUID. 
    */
   public String getUuid()
   {
      return uuid;
   }

   
   /**
    * Get user name.
    * 
    * @return  User name.
    */
   public String getUserName()
   {
      return userName;
   }

   /**
    * Set user name.
    * 
    * @param   userName
    *          User name.
    */
   public void setUserName(String userName)
   {
      this.userName = userName;
   }

   /**
    * Get user password;
    * 
    * @return  User password.
    */
   public String getPassword()
   {
      return password;
   }

   /**
    * Set user password.
    * 
    * @param   password
    *          User password;
    */

   public void setPassword(String password)
   {
      this.password = password;
   }

   /**
    * Get the security mode..
    * 
    * @return  <code>true</code> use a secured connection <code>false</code> otherwise.
    */
   public boolean isSecure()
   {
      return options.isSecure();
   }

   /**
    * Get classpath
    * 
    * @return  Class path string.
    */
   public String getClassPath()
   {
      return options.getClassPath();
   }

   /**
    * Get native library path.
    * 
    * @return  Native library path string.
    */
   public String getLibPath()
   {
      return options.getLibPath();
   }

   /**
    * Get user working directory.
    * 
    * @return  User working directory.
    */
   public String getWorkingDirectory()
   {
      return options.getWorkingDirectory();
   }

   /**
    * Get configuration file name.
    * 
    * @return  Configuration file name.
    */
   public String getConfigFile()
   {
      return options.getConfigFile();
   }
   
   /**
    * Get JVM arguments
    * 
    * @return  A List with JVM arguments.
    */
   public List<String> getJvmArguments()
   {
      return options.getJvmArguments();
   }

   /**
    * Get spawner command.
    * 
    * @return  The spawner command;
    */
   public String getSpawner()
   {
      return options.getSpawner();
   }

   /**
    * Get Terminal Options.
    * 
    * @return  The spawner command;
    */
   public Map<String, String> getTerminalOptions()
   {
      return options.getTerminalOptions();
   }

   /**
    * Get the Java process main class.
    * 
    * @return  The main class.
    */
   public Class<?> getMainClass()
   {
      return options.getMainClass();
   }
}
